@@ -341,7 +341,7 @@ def fetch_holidays(
     dates_to_remove = []
 
     if length and length < len(holi_days):
-        holdays_list = holi_days[:length]
+        holdays_list = list(holi_days)[:length]
 
         if returning in ('dict', 'dictionary'):
             for datum in holi_days:
