@@ -6,7 +6,6 @@ restricted_python_tools
 
 This module implements basic Python functionality missing in restricted Python.
 """
-from bs4 import BeautifulSoup
 
 
 def contains_all(
@@ -39,20 +38,6 @@ def contains_any(
     return any(el in container for el in contained)
 
 
-def prettify_html(
-    html: str
-) -> str:
-    """
-    Prettify html (from bs4/BeautifulSoup)
-
-    .. note:: This function is needed for Zope Python Scripts
-        because even if bs4 can be imported, prettify throws
-        an Unauthorized error in restricted Python
-    """
-
-    return BeautifulSoup(html, "html.parser").prettify()
-
-
 def remove_duplicates(lst: list) -> list:
     """ Removes duplicates from a list
 
