@@ -139,8 +139,9 @@ def could_be_a_name(
         if n[-1].isupper():
             return False
 
-        # more than 2 capitals
-        if sum(1 for c in n if c.isupper()) > 2:
+        # more than 2 capitals per word
+        n_words = len(n.split())
+        if sum(1 for c in n if c.isupper()) > n_words + 1:
             return False
 
     for n in (first, middle):
@@ -286,7 +287,7 @@ def map_special_chars(
 ) -> str:
     """ map special characters
 
-    .. note:: Umlauts are even recognized if the do not use the appropriate characters but
+    .. note:: Umlauts are even recognized if they do not use the appropriate characters but
               a vowel followed by a COMBINING DIAERESIS (U+0308) character instead.
 
     :param sort: case is preserved in any case. If you want lowercase, you have to feed
@@ -295,11 +296,7 @@ def map_special_chars(
     """
     text = normalize_text(text)
 
-    intab = 'AAAÁÀÂÃ?aaaáàâãå?CCCCccccçDÐddEEEEEÉÈÊËeeeeeéèêëGGggÍÌÎÏíìîïÓÒÔóòôõøñÚÙÛúùûÝýÿ'
-
-    if sort is False:
-        outtab = 'AAAAAAAAaaaaaaaaaCCCCcccccDDddEEEEEEEEEeeeeeeeeeGGggIIIIiiiiOOOooooonUUUuuuYyy'
-
+    if not sort:
         transDict = {
             'ä': 'ae',
             'Ä': 'Ae',
@@ -311,35 +308,11 @@ def map_special_chars(
             'æ': 'ae',
             'Æ': 'Ae'
         }
-    else:
-        outtab = 'AAAAAAAAaaaaaaaaaCCCCcccccDDddEEEEEEEEEeeeeeeeeeGGggIIIIiiiiOOOooooonUUUuuuYyy'
 
-        transDict = {
-            'ä': 'a',
-            'Ä': 'A',
-            'ö': 'o',
-            'Ö': 'O',
-            'ü': 'u',
-            'Ü': 'U',
-            'ß': 's',
-            'æ': 'a',
-            'Æ': 'A'
-        }
+        for key in list(transDict.keys()):
+            text = text.replace(key, transDict[key])
 
-    for it, ot in zip(intab, outtab):
-        transDict[it] = ot
-
-    try:
-        text + 1
-        text = str(text)
-    except Exception:
-        pass
-
-    # text = translate(text, transTable)
-    for key in list(transDict.keys()):
-        text = text.replace(key, transDict[key])
-
-    return text
+    return unidecode.unidecode(text)
 
 
 def normalize_text(
